Module handle

Structs

CosmosInstance
This is just a simple helper for running a Docker container with wasmd and cleaning up when done useful for integration tests that need a chain running

Enums

StdioKind