pub struct CosmosInstance {
pub chain_config: ChainConfig,
pub genesis_addresses: Vec<Address>,
pub name: String,
pub stdout: StdioKind,
pub stderr: StdioKind,
pub block_time: String,
pub image: String,
}Expand description
This is just a simple helper for running a Docker container with wasmd and cleaning up when done useful for integration tests that need a chain running
More advanced use-cases with other chains or more control should use third-party tools
This instance represents a running Docker container. When dropped, it will attempt to kill (and remove) the container automatically.
Fields
chain_config: ChainConfiggenesis_addresses: Vec<Address>name: Stringstdout: StdioKindstderr: StdioKindblock_time: Stringimage: StringImplementations